@@ -1,7 +1,10 @@
-
 #' @export
 str.AST <- function(
-  object, ..., max_level = -1, all_fields = FALSE, show_null = FALSE
+  object,
+  ...,
+  max_level = -1,
+  all_fields = FALSE,
+  show_null = FALSE
 ) {
   cat(
     format_str(
@@ -20,7 +23,9 @@ str_c_ret_spaces <- function(ret, spaces, ...) {
   dots <- collapse(...)
   if (spaces > 2) {
     second <- str_c(
-      "\n", collapse(rep(". ", floor((spaces - 2) / 2))), ". ",
+      "\n",
+      collapse(rep(". ", floor((spaces - 2) / 2))),
+      ". ",
       dots
     )
   } else if (spaces == 2) {
@@ -83,19 +88,11 @@ format_str <- function(
           for (item_pos in seq_along(field_val)) {
             field_item <- field_val[[item_pos]]
 
-            if (inherits(field_item, "FieldDefinition")) {
-              if (!isTRUE(field_item$.show_in_format)) {
-                if (!isTRUE(all_fields)) {
-                  next
-                }
-              }
-            }
-
-
             ret <- ret %>% str_c_ret_spaces(space_count + 4, item_pos, " - ")
 
             check_if_registered(field_item)
-            ret <- str_c(ret,
+            ret <- str_c(
+              ret,
               format_str(
                 field_item,
                 max_level = max_level - 1,
@@ -106,44 +103,54 @@ format_str <- function(
             )
           }
         }
-
       } else {
         # is value
         if (is.null(field_val)) {
           field_val <- "NULL"
           if (isTRUE(show_null)) {
-            ret <- ret %>% str_c_ret_spaces(space_count + 2, field_name, ": ", field_val)
+            ret <- ret %>%
+              str_c_ret_spaces(space_count + 2, field_name, ": ", field_val)
           }
         } else if (length(field_val) == 0) {
           if (isTRUE(show_null)) {
             ret <- ret %>%
-              str_c_ret_spaces(space_count + 2, field_name, ": ", typeof(field_val), "(0)")
+              str_c_ret_spaces(
+                space_count + 2,
+                field_name,
+                ": ",
+                typeof(field_val),
+                "(0)"
+              )
           }
         } else if (is.numeric(field_val)) {
-          ret <- ret %>% str_c_ret_spaces(space_count + 2, field_name, ": ", field_val)
+          ret <- ret %>%
+            str_c_ret_spaces(space_count + 2, field_name, ": ", field_val)
         } else if (is.character(field_val)) {
           if (length(field_val) == 0) {
             print("this should not happen")
             browser()
           }
-          ret <- ret %>% str_c_ret_spaces(space_count + 2, field_name, ": '", field_val, "'")
+          ret <- ret %>%
+            str_c_ret_spaces(space_count + 2, field_name, ": '", field_val, "'")
         } else if (is.logical(field_val)) {
-          ret <- ret %>% str_c_ret_spaces(space_count + 2, field_name, ": ", field_val)
+          ret <- ret %>%
+            str_c_ret_spaces(space_count + 2, field_name, ": ", field_val)
         } else if (is.function(field_val)) {
-          ret <- ret %>% str_c_ret_spaces(space_count + 2, field_name, ": ", "function")
+          ret <- ret %>%
+            str_c_ret_spaces(space_count + 2, field_name, ": ", "function")
         } else {
           print("type unknown (not char or number or bool). Fix this")
           browser()
           stop("type unknown (not char or number or bool). Fix this")
         }
       }
-
     } else {
       # recursive call to_string
       ret <- ret %>% str_c_ret_spaces(space_count + 2, field_name, ": ")
 
       check_if_registered(field_val)
-      ret <- str_c(ret,
+      ret <- str_c(
+        ret,
         format_str(
           field_val,
           max_level = max_level - 1,
