@@ -1,9 +1,5 @@
 # load_all(); testthat::test_file(file.path("tests", "testthat", "test-aaa-util.R")) # nolint
 
-context("Test helper functions")
-
-source(testthat::test_path("validate_helper.R"))
-
 test_that("chai tests", {
   tested_object <- list(
     a = "b",
@@ -12,7 +8,6 @@ test_that("chai tests", {
 
   expect_false(sub_rec(tested_object, list(a = "notB")))
 
-
   tested_object <- list(
     a = "b",
     c = "d",
@@ -39,12 +34,18 @@ test_that("chai tests", {
   )
   expect_subset(
     tested_object,
-    list(a = "b", c = "d", e = list(list(foo = "a"), list(foo = "bar", baz = list(qux = "quux"))))
+    list(
+      a = "b",
+      c = "d",
+      e = list(list(foo = "a"), list(foo = "bar", baz = list(qux = "quux")))
+    )
   )
 
   expect_false(sub_rec(
     tested_object,
-    list(e = list(list(foo = "a"), list(foo = "bar", baz = list(qux = "notAQuux"))))
+    list(
+      e = list(list(foo = "a"), list(foo = "bar", baz = list(qux = "notAQuux")))
+    )
   ))
 
   expect_false(sub_rec(
@@ -63,16 +64,10 @@ test_that("chai tests", {
     list(a = 1, b = "two", c = parent),
     list(c = parent)
   )
-
 })
 
 
-
-
-
-
 test_that("parse_ast()", {
-
   int_val <- IntValue$new(value = 5)
   bool_val <- BooleanValue$new(value = TRUE)
   float_val <- FloatValue$new(value = 5.0)
@@ -92,7 +87,6 @@ test_that("parse_ast()", {
   expect_equal(bool_lit(string_val), NULL)
   expect_equal(float_lit(string_val), NULL)
   expect_equal(string_lit(int_val), NULL)
-
 })
 
 
@@ -105,7 +99,6 @@ test_that("format()", {
     )
   )
 
-
   capture.output(print(dog_cat_doc)) %>%
     str_detect("__typename") %>%
     sum() %>%
@@ -114,41 +107,35 @@ test_that("format()", {
   capture.output(print(dog_cat_doc, all_fields = TRUE)) %>%
     str_detect("__typename") %>%
     sum() %>%
-    expect_equal(8)
-
+    expect_equal(0)
 })
 
 
 test_that("get_definition()", {
-
   dog_obj <- gqlr:::get_definition(dog_cat_schema, "Dog")
   expect_equal(format(dog_obj$name), "Dog")
-
 })
 
 
 test_that("PkgObjsGen()", {
-
   MyPkgObjs <- PkgObjs$clone()
   MyPkgObjs$add("Barret", "Value")
   expect_true(MyPkgObjs$is_registered("Barret"))
   expect_equal(MyPkgObjs$get_class_obj("Barret"), "Value")
   expect_true(!is.null(MyPkgObjs$names))
-
 })
 
 
 test_that("default active wrappers", {
-
   "
   {
     name
   }
   " %>%
-    gqlr:::graphql2obj() ->
-  query_doc
+    gqlr:::graphql2obj() -> query_doc
 
-  expect_error({
+  expect_error(
+    {
       query_doc$definitions[[1]]$operation <- "Barret"
     },
     "not in accepted values"
@@ -165,30 +152,32 @@ test_that("default active wrappers", {
     query: MyObject
   }
   " %>%
-    gqlr:::graphql2obj(parse_schema = TRUE) ->
-  doc
+    gqlr:::graphql2obj(parse_schema = TRUE) -> doc
 
   Barret <- doc$definitions[[1]]
 
-  expect_error({
+  expect_error(
+    {
       Barret$fields <- 5
     },
     "Attempting to set ObjectTypeDefinition"
   )
-  expect_error({
+  expect_error(
+    {
       Barret$fields[[1]] <- 5
     },
     "Attempting to set ObjectTypeDefinition"
   )
-  expect_error({
+  expect_error(
+    {
       Barret$directives <- 5
     },
     "\\|Directive\\|"
   )
-  expect_error({
+  expect_error(
+    {
       Barret$directives <- list(5)
     },
     "\\|Directive\\|"
   )
-
 })
