@@ -1,13 +1,6 @@
 # load_all(); testthat::test_file(file.path("tests", "testthat", "test-validation-5.2-fields.R")); # nolint
 
-context("validation-5.2-fields")
-
-
-source(testthat::test_path("validate_helper.R"))
-
-
 test_that("5.2.1 - Field Selections On Objects, Interfaces, and Union Types", {
-
   "
   {
     dog {
@@ -18,7 +11,7 @@ test_that("5.2.1 - Field Selections On Objects, Interfaces, and Union Types", {
     name
   }
   " %>%
-  expect_r6()
+    expect_r6()
 
   "
   {
@@ -33,8 +26,7 @@ test_that("5.2.1 - Field Selections On Objects, Interfaces, and Union Types", {
     name
   }
   " %>%
-  expect_r6()
-
+    expect_r6()
 
   "
   {
@@ -46,8 +38,7 @@ test_that("5.2.1 - Field Selections On Objects, Interfaces, and Union Types", {
     meowVolume
   }
   " %>%
-  expect_err("not all requested names are found")
-
+    expect_err("not all requested names are found")
 
   "
   {
@@ -59,8 +50,7 @@ test_that("5.2.1 - Field Selections On Objects, Interfaces, and Union Types", {
     nickname
   }
   " %>%
-  expect_err("not all requested names are found")
-
+    expect_err("not all requested names are found")
 
   "
   {
@@ -78,8 +68,7 @@ test_that("5.2.1 - Field Selections On Objects, Interfaces, and Union Types", {
     }
   }
   " %>%
-  expect_r6()
-
+    expect_r6()
 
   "
   {
@@ -92,18 +81,11 @@ test_that("5.2.1 - Field Selections On Objects, Interfaces, and Union Types", {
     barkVolume
   }
   " %>%
-  expect_err("fields may not be queried directly on a union object")
-
+    expect_err("fields may not be queried directly on a union object")
 })
 
 
-
-
-
-
-
 test_that("5.2.2 - Field Selection Merging", {
-
   "
   {
     dog {
@@ -120,7 +102,7 @@ test_that("5.2.2 - Field Selection Merging", {
     otherName: name
   }
   " %>%
-  expect_r6()
+    expect_r6()
 
   "
   {
@@ -133,8 +115,7 @@ test_that("5.2.2 - Field Selection Merging", {
     name
   }
   " %>%
-  expect_err("Two matching return fields must both be NonNullType")
-
+    expect_err("Two matching return fields must both be NonNullType")
 
   "
   query A {
@@ -156,7 +137,7 @@ test_that("5.2.2 - Field Selection Merging", {
     doesKnowCommand(dogCommand: $dogCommand)
   }
   " %>%
-  expect_r6()
+    expect_r6()
 
   "
   {
@@ -169,7 +150,7 @@ test_that("5.2.2 - Field Selection Merging", {
     doesKnowCommand(dogCommand: HEEL)
   }
   " %>%
-  expect_err("Two matching return fields must have identical arguments")
+    expect_err("Two matching return fields must have identical arguments")
 
   "
   query A($dogCommand: DogCommand = SIT) {
@@ -182,7 +163,7 @@ test_that("5.2.2 - Field Selection Merging", {
     doesKnowCommand(dogCommand: $dogCommand)
   }
   " %>%
-  expect_err("Two matching return fields must have identical arguments")
+    expect_err("Two matching return fields must have identical arguments")
 
   "
   query A($varOne: DogCommand = SIT, $varTwo: DogCommand = SIT) {
@@ -195,7 +176,7 @@ test_that("5.2.2 - Field Selection Merging", {
     doesKnowCommand(dogCommand: $varTwo)
   }
   " %>%
-  expect_err("Two matching return fields must have identical arguments")
+    expect_err("Two matching return fields must have identical arguments")
 
   "
   # validate fields can merge
@@ -208,7 +189,7 @@ test_that("5.2.2 - Field Selection Merging", {
     }
   }
   " %>%
-  expect_r6()
+    expect_r6()
 
   "
   # validate lists can merge
@@ -225,7 +206,7 @@ test_that("5.2.2 - Field Selection Merging", {
     }
   }
   " %>%
-  expect_r6()
+    expect_r6()
 
   "
   # validate lists can merge
@@ -244,8 +225,7 @@ test_that("5.2.2 - Field Selection Merging", {
     }
   }
   " %>%
-  expect_r6()
-
+    expect_r6()
 
   "
   {
@@ -271,8 +251,7 @@ test_that("5.2.2 - Field Selection Merging", {
     }
   }
   " %>%
-  expect_r6()
-
+    expect_r6()
 
   "
   {
@@ -291,17 +270,11 @@ test_that("5.2.2 - Field Selection Merging", {
     }
   }
   " %>%
-  expect_err("Two matching return names must return the same types")
-
-
+    expect_err("Two matching return names must return the same types")
 })
 
 
-
-
 test_that("5.2.3 - Leaf Field Selections", {
-
-
   "
   {
     dog {
@@ -312,7 +285,7 @@ test_that("5.2.3 - Leaf Field Selections", {
     barkVolume
   }
   " %>%
-  expect_r6()
+    expect_r6()
 
   "
   {
@@ -326,28 +299,26 @@ test_that("5.2.3 - Leaf Field Selections", {
     }
   }
   " %>%
-  expect_err("Not allowed to query deeper into leaf")
-
+    expect_err("Not allowed to query deeper into leaf")
 
   "
   query directQueryOnObjectWithoutSubFields {
     human
   }
   " %>%
-  expect_err("non leaf selection does not have any children")
+    expect_err("non leaf selection does not have any children")
 
   "
   query directQueryOnInterfaceWithoutSubFields {
     pet
   }
   " %>%
-  expect_err("non leaf selection does not have any children")
+    expect_err("non leaf selection does not have any children")
 
   "
   query directQueryOnUnionWithoutSubFields {
     catOrDog
   }
   " %>%
-  expect_err("non leaf selection does not have any children")
-
+    expect_err("non leaf selection does not have any children")
 })
