@@ -1,12 +1,6 @@
 # load_all(); testthat::test_file(file.path("tests", "testthat", "test-z-execute-mutation-simple.R")); # nolint
 
-
-context("execute-mutation-simple")
-
-source(testthat::test_path("validate_helper.R"))
-
 test_that("small counter", {
-
   count_total <- 0
   "
   type Counter {
@@ -36,9 +30,7 @@ test_that("small counter", {
           )
         }
       )
-    ) ->
-  mutation_schema_doc
-
+    ) -> mutation_schema_doc
 
   do_query <- function(i) {
     ans <- execute_request(
@@ -49,7 +41,10 @@ test_that("small counter", {
     )
     expect_true(ans$error_list$has_no_errors())
     expect_equal(ans$data$value, i)
-    expect_equal(format(ans, pretty = FALSE), str_c("{\"data\":{\"value\":", i, "}}"))
+    expect_equal(
+      format(ans, pretty = FALSE),
+      str_c("{\"data\":{\"value\":", i, "}}")
+    )
   }
 
   do_mutation <- function(i) {
@@ -68,6 +63,49 @@ test_that("small counter", {
     do_query(i)
     do_mutation(i + 1)
   }
+})
 
+# Altered from: https://github.com/schloerke/gqlr/issues/8
+test_that("mutation works with names that are not query names", {
+  votes <- 3
 
+  "
+  type Query {
+    votes: Int!
+  }
+
+  type Mutation {
+    castVote: Boolean!
+  }
+
+  schema {
+    query: Query
+    mutation: Mutation
+  }
+  " %>%
+    gqlr_schema(
+      Query = function(...) {
+        list(votes = function(...) {
+          votes
+        })
+      },
+      Mutation = function(...) {
+        list(castVote = function(...) {
+          votes <<- 42
+          # Return TRUE to indicate that the mutation was successful
+          TRUE
+        })
+      }
+    ) -> votes_schema
+
+  expect_votes_request <- function(...) {
+    expect_request(..., schema = votes_schema)
+  }
+
+  "{votes}" %>%
+    expect_votes_request('{ "data": { "votes": 3 } }')
+  "mutation Cast { castVote }" %>%
+    expect_votes_request('{ "data": { "castVote": true } }')
+  "{votes}" %>%
+    expect_votes_request('{ "data": { "votes": 42 } }')
 })
