@@ -1,13 +1,5 @@
-
-
 # load_all(); testthat::test_file(file.path("tests", "testthat", "test-zz-star_wars.R")); # nolint
 
-context("star wars")
-
-source(testthat::test_path("validate_helper.R"))
-
-source(file.path("star_wars_schema.R"))
-
 expect_sw_err <- function(...) {
   expect_err(..., schema = star_wars_schema) # nolint
 }
@@ -22,12 +14,7 @@ expect_sw_request_err <- function(...) {
 }
 
 
-
-source(testthat::test_path("validate_helper.R"))
-
-
 test_that("star wars test suite", {
-
   "
   query HeroNameQuery {
     hero {
@@ -43,7 +30,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   {
     hero {
@@ -59,7 +45,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   query HeroNameAndFriendsQuery {
     hero {
@@ -95,7 +80,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   query NestedQuery {
     hero {
@@ -149,7 +133,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   query FetchLukeQuery {
     human(id: \"1000\") {
@@ -183,7 +166,6 @@ test_that("star wars test suite", {
       )
     )
 
-
   "
   query FetchLukeAliased {
     luke: human(id: \"1000\") {
@@ -199,7 +181,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   query FetchLukeAndLeiaAliased {
     luke: human(id: \"1000\") {
@@ -221,7 +202,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   query UseFragment {
     luke: human(id: \"1000\") {
@@ -266,7 +246,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   query CheckTypeOfR2 {
     hero {
@@ -284,7 +263,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   query CheckTypeOfLuke {
     hero(episode: EMPIRE) {
@@ -302,7 +280,6 @@ test_that("star wars test suite", {
       }}'
     )
 
-
   "
   query NestedQueryWithFragment {
     hero {
@@ -386,13 +363,10 @@ test_that("star wars test suite", {
         }
       }}'
     )
-
 })
 
 
 test_that("validation", {
-
-
   "
   # INVALID: favoriteSpaceship does not exist on Character
   query HeroSpaceshipQuery {
@@ -461,10 +435,7 @@ test_that("validation", {
 })
 
 
-
-
 test_that("introspection", {
-
   "
   query IntrospectionTypeQuery {
     __schema {
@@ -590,8 +561,7 @@ test_that("introspection", {
             {"name": "name","type": {"name": "String","kind": "SCALAR"}},
             {"name": "friends","type": {"name": null,"kind": "LIST"}},
             {"name": "appearsIn","type": {"name": null,"kind": "LIST"}},
-            {"name": "primaryFunction","type": {"name": "String","kind": "SCALAR"}},
-            {"name": "__typename","type": {"name": "String","kind": "SCALAR"}}
+            {"name": "primaryFunction","type": {"name": "String","kind": "SCALAR"}}
           ]
         }
       }}'
@@ -639,10 +609,6 @@ test_that("introspection", {
       {
         "name": "primaryFunction",
         "type": {"name": "String","kind": "SCALAR","ofType": null}
-      },
-      {
-        "name": "__typename",
-        "type": {"name": "String","kind": "SCALAR","ofType": null}
       }
           ]
         }
@@ -665,14 +631,10 @@ test_that("introspection", {
         }
       }}'
     )
-
-
 })
 
 
-
 test_that("operations", {
-
   "
   query IntrospectionDroidDescriptionQuery {
     __type(name: \"Droid\") {
@@ -718,12 +680,10 @@ test_that("operations", {
       }'
       # nolint end
     )
-
 })
 
 
 test_that("directives", {
-
   "
   query FetchLukeAndLeiaAliased {
     luke: human(id: \"1000\") @skip(if: false)  {
@@ -783,13 +743,10 @@ test_that("directives", {
       }'
       # nolint end
     )
-
 })
 
 
-
 test_that("variables", {
-
   "
   query Variable($someId: String!) {
     __type(name: $someId) {
@@ -877,5 +834,4 @@ test_that("variables", {
       }'
       # nolint end
     )
-
 })
